#
# spec file for package perl-Twiggy
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Twiggy
Name:           perl-Twiggy
Version:        0.1026
Release:        bp156.2.1
Summary:        AnyEvent HTTP server for PSGI
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MIYAGAWA/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(AnyEvent)
BuildRequires:  perl(HTTP::Status)
BuildRequires:  perl(Plack) >= 0.99
BuildRequires:  perl(Test::Requires)
BuildRequires:  perl(Test::TCP)
BuildRequires:  perl(Try::Tiny)
Requires:       perl(AnyEvent)
Requires:       perl(HTTP::Status)
Requires:       perl(Plack) >= 0.99
Requires:       perl(Try::Tiny)
%{perl_requires}

%description
Twiggy is a lightweight and fast HTTP server with unique features such as:

* PSGI

Can run any PSGI applications. Fully supports _psgi.nonblocking_ and
_psgi.streaming_ interfaces.

* AnyEvent

This server uses AnyEvent and runs in a non-blocking event loop, so it's
best to run event-driven web applications that runs I/O bound jobs or
delayed responses such as long-poll, WebSocket or streaming content (server
push).

This software used to be called Plack::Server::AnyEvent but was renamed to
Twiggy.

* Fast header parser

Uses XS/C based HTTP header parser for the best performance. (optional,
install the HTTP::Parser::XS module to enable it; see also
Plack::HTTPParser for more information).

* Lightweight and Fast

The memory required to run twiggy is 6MB and it can serve more than 4500
req/s with a single process on Perl 5.10 with MacBook Pro 13" late 2009.

* Superdaemon aware

Supports Server::Starter for hot deploy and graceful restarts.

To use it, instead of the usual:

    plackup --server Twiggy --port 8111 app.psgi

install Server::Starter and use:

    start_server --port 8111 -- plackup --server Twiggy app.psgi

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Fri Jan 22 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.1026
  see /usr/share/doc/packages/perl-Twiggy/Changes
  0.1026  2021-01-20 23:01:13 PST
  - Improved documentation
* Wed Nov 25 2020 Frank Schreiner <FSchreiner@suse.com>
- re-run cpanspec
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.1025
  see /usr/share/doc/packages/perl-Twiggy/Changes
  0.1025  2015-01-04 07:00:16 JST
  - Fix a bug where Twiggy's run loop exits after a streaming request is cut off (hoelzro) #41
  0.1024  2013-10-12 11:35:35 PDT
  - Fix a bug where exit_guard is not correctly decremented when writing header failed (maedama) #37
  0.1023  2013-06-15 01:51:22 PDT
  - Move the bin directory (moznion) #35
  0.1022  2013-06-12 12:36:16 PDT
  - convert to use Milla
  - Fix dependency for LWP
  0.1021 Fri Oct 19 15:09:17 PDT 2012
  - Repackage with the latest Module::Install
  0.1020 Mon Feb 20 16:31:44 PST 2012
  - Improve SEREVR_PORT when binding multiple ports
  - Documentation fixes (Pedro Melo)
  - Suppres 400 if client disconnected (athomason)
  - Don't restrict parsing the request body to PUT and POST requests (Moritz Onken)
  - Fixed broken POST data processing (und3f, hidekiy)
  0.1010 Mon Jan 17 17:04:14 PST 2011
  - Returning CondVar as a PSGI response is deprecated. Will be removed in the next release
  0.1009 Fri Dec  3 11:52:20 PST 2010
  - Fixed leaking fd (t0m)
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.1010
  see /usr/share/doc/packages/perl-Twiggy/Changes
  0.1010 Mon Jan 17 17:04:14 PST 2011
  - Returning CondVar as a PSGI response is deprecated. Will be removed in the next release
  0.1009 Fri Dec  3 11:52:20 PST 2010
  - Fixed leaking fd (t0m)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Oct  7 2010 pascal.bleser@opensuse.org
- initial package (0.1008)
